==> eam-wshub-proxyclient-11.6-0-sources.jar: net/datastream/schemas/mp_fields/EMPLOYEEPROPERTYID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour EMPLOYEEPROPERTYID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="EMPLOYEEPROPERTYID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EMPLOYEECODE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PROPERTY"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "EMPLOYEEPROPERTYID_Type", propOrder = {
    "employeecode",
    "property"
})
public class EMPLOYEEPROPERTYID_Type {

    @XmlElement(name = "EMPLOYEECODE", required = true)
    protected String employeecode;
    @XmlElement(name = "PROPERTY", required = true)
    protected String property;

    /**
     * Obtient la valeur de la propriété employeecode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getEMPLOYEECODE() {
        return employeecode;
    }

    /**
     * Définit la valeur de la propriété employeecode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setEMPLOYEECODE(String value) {
        this.employeecode = value;
    }

    /**
     * Obtient la valeur de la propriété property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPROPERTY() {
        return property;
    }

    /**
     * Définit la valeur de la propriété property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPROPERTY(String value) {
        this.property = value;
    }

}

==> eam-wshub-proxyclient-12.0-sources.jar: net/datastream/schemas/mp_fields/EMPLOYEEPROPERTYID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for EMPLOYEEPROPERTYID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="EMPLOYEEPROPERTYID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EMPLOYEECODE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PROPERTY"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "EMPLOYEEPROPERTYID_Type", propOrder = {
    "employeecode",
    "property"
})
public class EMPLOYEEPROPERTYID_Type {

    @XmlElement(name = "EMPLOYEECODE", required = true)
    protected String employeecode;
    @XmlElement(name = "PROPERTY", required = true)
    protected String property;

    /**
     * Gets the value of the employeecode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getEMPLOYEECODE() {
        return employeecode;
    }

    /**
     * Sets the value of the employeecode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setEMPLOYEECODE(String value) {
        this.employeecode = value;
    }

    /**
     * Gets the value of the property property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPROPERTY() {
        return property;
    }

    /**
     * Sets the value of the property property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPROPERTY(String value) {
        this.property = value;
    }

}
